module java.jws {
    exports javax.jws;
    exports javax.jws.soap;

}

